#
# pg_secured::controls::correct_messages_are_written_to_the_server_log
#
# @summary The log_min_messages setting specifies the message levels that are written to
# the server log. Each level includes all the levels that follow it. The lower the
# level (vertically, below), the fewer messages are sent. Valid values are:
# - DEBUG5 <-- exceedingly chatty
# - DEBUG4
# - DEBUG3
# - DEBUG2
# - DEBUG1
# - INFO
# - NOTICE
# - WARNING
# - ERROR
# - LOG
# - FATAL
# - PANIC <-- practically mute WARNING is considered the best practice unless
#   indicated otherwise by your organization's logging policy.
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/pg_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Postgres Database 13 CIS V1.0.0](/docs/pg_secured/cis/pg13_V1.0.0.html) - paragraph 3.1.12
# - [Postgres Database 14 CIS V1.0.0](/docs/pg_secured/cis/pg14_V1.0.0.html) - paragraph 3.1.14
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `pg_secured::controls::correct_messages_are_written_to_the_server_log: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `pg_secured::controls::correct_messages_are_written_to_the_server_log::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `correct_messages_are_written_to_the_server_log` to the array value `pg_secured::skip_list` in your hiera data.
#
# @param title
#    The instance to apply the control to.
#    All controls need an instance to apply the control to. Here is a simple example:
#    ``` puppet
#    pg_secured::controls::control_name { 'instance':}
#    ```
#    In this example, the string `instance` is the instance to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define pg_secured::controls::correct_messages_are_written_to_the_server_log {
  pg_secured_setup { "correct_messages_are_written_to_the_server_log on ${title}":
    ensure => 'present',
  }

  -> pg_secured::internal::set_parameter { "log_min_messages@${title}":
    value => 'warning',
  }
}
