#
# pg_secured::controls::correct_syslog_facility_is_selected
#
# @summary The syslog_facility setting specifies the syslog "facility" to be used when
# logging to syslog is enabled. You can choose from any of the 'local' facilities:
# • LOCAL0 • LOCAL1 • LOCAL2 • LOCAL3 • LOCAL4 • LOCAL5 • LOCAL6 • LOCAL7 Your
# organization's logging policy should dictate which facility to use based on the
# syslog daemon in use.
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/pg_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Postgres Database 10 CIS V1.0.0](/docs/pg_secured/cis/pg10_V1.0.0.html) - paragraph 3.1.10
# - [Postgres Database 11 CIS V1.0.0](/docs/pg_secured/cis/pg11_V1.0.0.html) - paragraph 3.1.10
# - [Postgres Database 12 CIS V1.0.0](/docs/pg_secured/cis/pg12_V1.0.0.html) - paragraph 3.1.10
# - [Postgres Database 13 CIS V1.0.0](/docs/pg_secured/cis/pg13_V1.0.0.html) - paragraph 3.1.10
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `pg_secured::controls::correct_syslog_facility_is_selected: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `pg_secured::controls::correct_syslog_facility_is_selected::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `correct_syslog_facility_is_selected` to the array value `pg_secured::skip_list` in your hiera data.
#
# @param title
#    The instance to apply the control to.
#    All controls need an instance to apply the control to. Here is a simple example:
#    ``` puppet
#    pg_secured::controls::control_name { 'instance':}
#    ```
#    In this example, the string `instance` is the instance to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define pg_secured::controls::correct_syslog_facility_is_selected {
  pg_secured_setup { "correct_syslog_facility_is_selected on ${title}":
    ensure => 'present',
  }

  -> pg_secured::internal::set_parameter { "syslog_facility@${title}":
    value => 'local1',
  }
}
