#
# pg_secured::controls::debug_print_plan_is_disabled
#
# @summary The debug_print_plan setting enables printing the execution plan for each executed query.
# These messages are emitted at the LOG message level. Unless directed otherwise by your organization's logging policy, it is recommended this setting be disabled by setting it to off.
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/pg_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Postgres Database 10 CIS V1.0.0](/docs/pg_secured/cis/pg10_V1.0.0.html) - paragraph 3.1.16
# - [Postgres Database 11 CIS V1.0.0](/docs/pg_secured/cis/pg11_V1.0.0.html) - paragraph 3.1.16
# - [Postgres Database 12 CIS V1.0.0](/docs/pg_secured/cis/pg12_V1.0.0.html) - paragraph 3.1.16
# - [Postgres Database 13 CIS V1.0.0](/docs/pg_secured/cis/pg13_V1.0.0.html) - paragraph 3.1.16
# - [Postgres Database 14 CIS V1.0.0](/docs/pg_secured/cis/pg14_V1.0.0.html) - paragraph 3.1.18
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `pg_secured::controls::debug_print_plan_is_disabled: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `pg_secured::controls::debug_print_plan_is_disabled::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `debug_print_plan_is_disabled` to the array value `pg_secured::skip_list` in your hiera data.
#
# @param title
#    The instance to apply the control to.
#    All controls need an instance to apply the control to. Here is a simple example:
#    ``` puppet
#    pg_secured::controls::control_name { 'instance':}
#    ```
#    In this example, the string `instance` is the instance to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define pg_secured::controls::debug_print_plan_is_disabled {
  pg_secured_setup { "debug_print_plan_is_disabled on ${title}":
    ensure => 'present',
  }

  -> pg_secured::internal::set_parameter { "debug_print_plan@${title}":
    value => 'off',
  }
}
