#
# pg_secured::controls::log_error_verbosity_is_set_correctly
#
# @summary The log_error_verbosity setting specifies the verbosity (amount of detail) of
# logged messages. Valid values are:
# 
# - TERSE
# - DEFAULT
# - VERBOSE 
#  
# with each containing the fields of the level above it as well as additional fields. TERSE
# excludes the logging of DETAIL, HINT, QUERY, and CONTEXT error information.
# VERBOSE output includes the SQLSTATE, error code, and the source code file name,
# function name, and line number that generated the error. The appropriate value
# should be set based on your organization's logging policy.
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/pg_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Postgres Database 13 CIS V1.0.0](/docs/pg_secured/cis/pg13_V1.0.0.html) - paragraph 3.1.20
# - [Postgres Database 14 CIS V1.0.0](/docs/pg_secured/cis/pg14_V1.0.0.html) - paragraph 3.1.22
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `pg_secured::controls::log_error_verbosity_is_set_correctly: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `pg_secured::controls::log_error_verbosity_is_set_correctly::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `log_error_verbosity_is_set_correctly` to the array value `pg_secured::skip_list` in your hiera data.
#
# @param title
#    The instance to apply the control to.
#    All controls need an instance to apply the control to. Here is a simple example:
#    ``` puppet
#    pg_secured::controls::control_name { 'instance':}
#    ```
#    In this example, the string `instance` is the instance to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define pg_secured::controls::log_error_verbosity_is_set_correctly {
  pg_secured_setup { "log_error_verbosity_is_set_correctly on ${title}":
    ensure => 'present',
  }

  -> pg_secured::internal::set_parameter { "log_error_verbosity@${title}":
    value => 'verbose',
  }
}
