#
# pg_secured::controls::use_pg_permission_extension_to_audit_object_permissions
#
# @summary Using a PostgreSQL extension called pg_permissions it is possible to declare which DB users should have which permissions on a given object and generate a report showing compliance/deviation.
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/pg_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Postgres Database 13 CIS V1.0.0](/docs/pg_secured/cis/pg13_V1.0.0.html) - paragraph 4.5
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `pg_secured::controls::use_pg_permission_extension_to_audit_object_permissions: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `pg_secured::controls::use_pg_permission_extension_to_audit_object_permissions::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `use_pg_permission_extension_to_audit_object_permissions` to the array value `pg_secured::skip_list` in your hiera data.
#
# @param title
#    The instance to apply the control to.
#    All controls need an instance to apply the control to. Here is a simple example:
#    ``` puppet
#    pg_secured::controls::control_name { 'instance':}
#    ```
#    In this example, the string `instance` is the instance to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define pg_secured::controls::use_pg_permission_extension_to_audit_object_permissions (
  String[1] $ensure_libraries = 'pg_secured::ensure_pg_permissions_libraries'
) {
  pg_secured_setup { "use_pg_permission_extension_to_audit_object_permissions on ${title}":
    ensure => 'present',
  }

  if $facts['pg_major_version'] != undef {
    pg_secured::internal::ensure_extension { "pg_permissions@${title}":
      ensure_libraries => $ensure_libraries,
      require          => Pg_secured_setup["use_pg_permission_extension_to_audit_object_permissions on ${title}"],
    }
  } else {
    warning 'Postgres version not (yet) known. Skipping this control for now'
  }
}
